@@ -244,15 +244,13 @@ inbrackets :: TP Exp
 inbrackets = (brackets $ manyExp $ notFollowedBy (char ']') >> expr)
 
 number :: TP Exp
-number = lexeme $ ENumber <$> decimalNumber
-  where decimalNumber = try $ do
+number = lexeme $ ENumber <$> try decimalNumber
+  where decimalNumber = do
           xs <- many digit
-          pt <- option "" (string ".")
-          if null pt
-             then if null xs
-                     then mzero
-                     else return xs
-             else ((xs ++ pt) ++) <$> many1 digit
+          ys <- option [] $ try (char '.' >> (('.':) <$> many1 digit))
+          case xs ++ ys of
+               []  -> mzero
+               zs  -> return zs
 
 enclosure :: TP Exp
 enclosure = basicEnclosure <|> scaledEnclosure <|> delimited
@@ -719,6 +717,8 @@ symbols = M.fromList
            , ("\\backslash", ESymbol Bin "\x2216")
            , ("\\setminus", ESymbol Bin "\\")
            , ("\\times", ESymbol Bin "\x00D7")
+           , ("\\ltimes", ESymbol Bin "\x22C9")
+           , ("\\rtimes", ESymbol Bin "\x22CA")
            , ("\\alpha", EIdentifier "\x03B1")
            , ("\\beta", EIdentifier "\x03B2")
            , ("\\chi", EIdentifier "\x03C7")
@@ -969,6 +969,7 @@ regular = many1 (noneOf "`'-~${}\\ \t")
 ligature :: TP String
 ligature = try ("\x2014" <$ string "---")
        <|> try ("\x2013" <$ string "--")
+       <|> try (string "-")
        <|> try ("\x201C" <$ string "``")
        <|> try ("\x201D" <$ string "''")
        <|> try ("\x2019" <$ string "'")
